(communications-docs)=
# AutoTrader Communications Subpackage

(emailing-utils)=
## Emailing Utilities


```{eval-rst}
.. automodule:: autotrader.comms.emailing
    :members:
```



## Future Implementations
Plans for telegram bot control.